@@ -2,8 +2,9 @@
 ## - pinned versions were obtained from
 ## https://github.com/csoneson/orthos_package_list
 
-if (basilisk.utils::isLinuxAarch64()) {
+if (basilisk::isLinuxAarch64()) {
     .orthos_dependencies <- c(
+        "python==3.12",
         "absl-py==2.3.1",
         "astunparse==1.6.3",
         "certifi==2025.8.3",
@@ -49,8 +50,9 @@ if (basilisk.utils::isLinuxAarch64()) {
         "wheel==0.45.1",
         "wrapt==1.17.3"
     )
-} else if (basilisk.utils::isLinux()) {
+} else if (basilisk::isLinux()) {
     .orthos_dependencies <- c(
+        "python==3.12",
         "absl-py==2.3.1",
         "astunparse==1.6.3",
         "certifi==2025.8.3",
@@ -96,8 +98,9 @@ if (basilisk.utils::isLinuxAarch64()) {
         "wheel==0.45.1",
         "wrapt==1.17.3"
     )
-} else if (basilisk.utils::isMacOSXArm()) {
+} else if (basilisk::isMacOSXArm()) {
     .orthos_dependencies <- c(
+        "python==3.12",
         "absl-py==2.3.1",
         "astunparse==1.6.3",
         "certifi==2025.8.3",
@@ -143,8 +146,9 @@ if (basilisk.utils::isLinuxAarch64()) {
         "wheel==0.45.1",
         "wrapt==1.17.3"
     )
-} else if (basilisk.utils::isMacOSX()) {
+} else if (basilisk::isMacOSX()) {
     .orthos_dependencies <- c(
+        "python==3.12",
         "absl-py==2.3.1",
         "astunparse==1.6.3",
         "certifi==2025.8.3",
@@ -190,8 +194,9 @@ if (basilisk.utils::isLinuxAarch64()) {
         "wheel==0.45.1",
         "wrapt==1.17.3"
     )
-} else if (basilisk.utils::isWindows()) {
+} else if (basilisk::isWindows()) {
     .orthos_dependencies <- c(
+        "python==3.12",
         "absl-py==2.3.1",
         "astunparse==1.6.3",
         "certifi==2025.8.3",
@@ -244,7 +249,5 @@ if (basilisk.utils::isLinuxAarch64()) {
 #' @importFrom basilisk BasiliskEnvironment
 orthosenv <- basilisk::BasiliskEnvironment(
     envname = "orthos", pkgname = "orthos",
-    packages = "python==3.12",
-    pip = .orthos_dependencies,
-    channels = "conda-forge"
+    packages = .orthos_dependencies
 )
